@@ -7,7 +7,7 @@ from .logclasses import PolyaxonLogger
 from .logclasses import PyLogger
 from .logclasses import TensorboardLogger
 
-__version__ = '0.0.0'
+__version__ = "0.0.2"
 
 # Set default logging handler to avoid "No handler found" warnings.
 logging.getLogger(__name__).addHandler(logging.NullHandler())
@@ -18,4 +18,4 @@ __all__ = [
     if module != "__init__.py" and module[-3:] == ".py"
 ]
 
-__all__ += ['Logger', 'TensorboardLogger', 'PyLogger', 'MLFlowLogger', 'PolyaxonLogger']
+__all__ += ["Logger", "TensorboardLogger", "PyLogger", "MLFlowLogger", "PolyaxonLogger"]
